<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtro:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Seleccione la fuente de la terminal</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Fuente:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Tamaño:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Vista previa</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Presione &quot;%1&quot; para ver la terminal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>Limpiar la terminal a&amp;ctiva</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>Pestaña siguie&amp;nte</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Pestaña anterior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Pestaña anterior en el historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>Siguie&amp;nte pestaña en el historial</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>Mover la pestaña a &amp;la izquierda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Mover la pestaña a la de&amp;recha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>Pestaña</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>Ir a</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Dividir la terminal en &amp;horizontal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Dividir la terminal en &amp;vertical</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Colapsar la terminal dividida</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Terminal dividida superior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>Terminal dividida inferior</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>T&amp;erminal dividida izquierda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>Term&amp;inal dividida derecha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>Copiar la &amp;selección</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>Pegar el portapapeles</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>Pegar la s&amp;elección</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>Ampl&amp;iar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>Reducir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>Reiniciar el zum</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation>Administrar historial...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>Guardar la &amp;sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>Cargar sesión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>Conmu&amp;tar el menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Renombrar la session</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nueva pestaña</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nueva pestaña desde &amp;preajuste</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 terminales &amp;horizontales</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 terminales &amp;verticales</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 terminale&amp;s</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Cerrar la pestaña</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nueva ventana</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferencias...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>Ocultar el borde de las ventanas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>Mo&amp;strar la barra de pestañas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Pantalla completa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Conmutar los marcadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>A&amp;bajo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>De&amp;recha</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>Diseño de pes&amp;tañas</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>&amp;Ninguno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Diseño de barras de de&amp;splazamiento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>Forma del cursor del teclado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Salir de QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>No volver a preguntar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>¿Está seguro de querer salir?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>Un emulador de terminal liviano multiplataforma</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="586"/>
        <source>Emulation</source>
        <translation>Emulación</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Atajos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Configuración de la terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="611"/>
        <source>Behavior</source>
        <translation>Comportamiento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Desplegable</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Ocultar la barra de pestañas si hay una sola pestaña</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Esquema de color</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="371"/>
        <source>Scrollbar position</source>
        <translation>Posición de la barra de desplazamiento</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Iniciar con el preajuste:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="404"/>
        <source>Show a border around the current terminal</source>
        <translation>Mostrar un borde alrededor de la terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="381"/>
        <source>Terminal transparency</source>
        <translation>Transparencia de la terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="394"/>
        <source>Application transparency</source>
        <translation>Transparencia de la aplicación</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Ninguno (terminal única)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminales en horizontal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 terminales en vertical</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminales</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Fuente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Cambiar...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="454"/>
        <source>Tabs position</source>
        <translation>Posición de las pestañas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Estilo de los controles</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Mostrar la barra de menú</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="464"/>
        <source>Change window title based on current terminal</source>
        <translation>Cambiar el título de la ventana según la terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="481"/>
        <source>Change window icon based on current terminal</source>
        <translation>Cambiar el icono de la ventana según la terminal actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Enable bi-directional text support</source>
        <translation>Habilitar el soporte de texto bidireccional</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Imagen de fondo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Seleccionar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="488"/>
        <source>Show terminal size on resize</source>
        <translation>Mostrar el tamaño de la terminal al cambiar de tamaño</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="411"/>
        <location filename="../forms/propertiesdialog.ui" line="444"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="361"/>
        <source>Show close button on each tab</source>
        <translation>Mostrar el botón de cerrar en cada pestaña</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Margen de la terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="498"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Usar los caracteres para dibujar cajas contenidos en la fuente</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="505"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Los atajos de teclado se activan con Alt y pueden interferir con la terminal.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="508"/>
        <source>No menu bar accelerator</source>
        <translation>No hay atajo de teclado para la barra del menú</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="711"/>
        <source>Action after paste</source>
        <translation>Acción tras pegar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="748"/>
        <source>Confirm multiline paste</source>
        <translation>Pedir confirmación al pegar varias líneas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="789"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Eliminar los saltos de línea del texto pegado</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="724"/>
        <source>Open new terminals in current working directory</source>
        <translation>Abrir las terminales nuevas en el directorio de trabajo actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="755"/>
        <source>Save Size when closing</source>
        <translation>Guardar el tamaño al cerrar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="796"/>
        <source>Save Position when closing</source>
        <translation>Guardar la posición al cerrar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="772"/>
        <source>Ask for confirmation when closing</source>
        <translation>Pedir confirmación al cerrar</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="816"/>
        <source>Unlimited history</source>
        <translation>Historial ilimitado</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="782"/>
        <source>History size (in lines)</source>
        <translation>Tamaño del historial (en líneas)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="741"/>
        <source>Default $TERM</source>
        <translation>$TERM por omisión</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="632"/>
        <source>Start with this size:</source>
        <translation>Iniciar con este tamaño:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Background mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="307"/>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="312"/>
        <source>Stretch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="317"/>
        <source>Zoom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="322"/>
        <source>Fit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="327"/>
        <source>Center</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="495"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Especifica si se deben dibujar los caracteres de dibujo de caja por QTerminal de forma interna o se deja a las bibliotecas de representación de fuentes subyacentes.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="515"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Alterna el uso de fuente en negrita para mostrar colores intensos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="518"/>
        <source>Use bold font face for intense colors</source>
        <translation>Usa fuentes en negrita para colores intensos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="525"/>
        <source>&amp;Hide Window Borders</source>
        <translation type="unfinished">Ocultar el borde de las ventanas</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="595"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt; &lt;p&gt;Cuál comportamiento emular. Tenga en cuenta que esto no tiene que coincidir con su sistema operativo.&lt;/p&gt; &lt;p&gt; Si no está seguro, utilice la emulación &lt;span style = &quot;font-weight: 600;&quot;&gt; predeterminada &lt;/span&gt;. &lt;/p&gt; &lt;/body&gt; &lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Este comando correrá con un argumento conteniendo el nombre de archivo de un archivo temporal conteniendo el historial de scrollback</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="620"/>
        <source>Handle history command</source>
        <translation>Administrar historial de comandos</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="639"/>
        <location filename="../forms/propertiesdialog.ui" line="653"/>
        <source> px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="660"/>
        <source>Get current size</source>
        <translation>Obtener el tamaño actual</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="731"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Abrir una nueva pestaña a la derecha de la pestaña activa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="734"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Si está sin seleccionar, la nueva pestaña será abierta en la posición extrema derecha</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="762"/>
        <source>Close tab on middle-click</source>
        <translation>Cierra pestaña con botón de en medio</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="823"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="826"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="844"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Para editar un acceso directo:
1. Haga doble clic en su clave
2. Presione la combinación deseada y suéltela
3. Haga clic en un acceso directo o presione Entrar

Para eliminar / deshabilitar un acceso directo, en el punto 2 presione solo un modificador (como Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="909"/>
        <source>Height</source>
        <translation>Alto</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="919"/>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="926"/>
        <source>Width</source>
        <translation>Ancho</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="982"/>
        <source>Edit bookmark file contents</source>
        <translation>Editar el contenido del archivo de marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1004"/>
        <source>Enable bookmarks</source>
        <translation>Habilitar los marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1013"/>
        <source>Bookmark file</source>
        <translation>Añadir el fichero a marcadores</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="891"/>
        <source>Show on start</source>
        <translation>Mostrar al inicio</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Cursor shape</source>
        <translation>Forma del cursor</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="471"/>
        <source>Fixed tab width:</source>
        <translation>Ancho fijo de pestaña:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="898"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="950"/>
        <source>Shortcut:</source>
        <translation>Atajo:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1026"/>
        <source>Find...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1035"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Puedes especificar la ubicación de su propio archivo de marcadores. Permite facilmente compartir marcadores con herramientas como OwnCloud o Dropbox.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="425"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="874"/>
        <source>Shortcut</source>
        <translation>Acción</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="879"/>
        <source>Key</source>
        <translation>Acceso rápido</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <source>No scrollbar</source>
        <translation>Sin barras de desplazamiento</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Left</source>
        <translation>Izquierda</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="155"/>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Right</source>
        <translation>Derecha</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Top</source>
        <translation>Arriba</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="161"/>
        <source>Bottom</source>
        <translation>Abajo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>BlockCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>UnderlineCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="174"/>
        <source>IBeamCursor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>No move</source>
        <translation>No mover</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="192"/>
        <source>Scrolling to bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="390"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="199"/>
        <location filename="../propertiesdialog.cpp" line="294"/>
        <source>System Default</source>
        <translation>Por defecto del sistema</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="389"/>
        <source>Choose a background image</source>
        <translation>Elija una imagen de fondo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="466"/>
        <source>Open or create bookmarks file</source>
        <translation>Abrir o crear archivo de marcadores</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Marcadores locales</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Marcadores sincronizados</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Terminal nro. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Nombre de la pestaña</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Nuevo nombre de la pestaña:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Seleccione el color del título de las pestañas nuevas</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Cerrar la session</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Cambiar el color del título</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Cargar session</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Lista de sessiones guardadas:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Ventana principal</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>Archivo</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Acciones</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>Ayuda</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vista</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Acerca de...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Acerca de &amp;Qt...</translation>
    </message>
</context>
</TS>
